
/*     *******************************************************************************
	XVisual GUI Development System for Linux/X-Window
	Copyright (C) 1996 Steve Carrie.

        This program is free software; you can redistribute it and/or modify
        it under the terms of the GNU General Public License as published by
        the Free Software Foundation; either version 2 of the License, or
        (at your option) any later version.

        This program is distributed in the hope that it will be useful,
        but WITHOUT ANY WARRANTY; without even the implied warranty of
        MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
        GNU General Public License for more details.

        You should have received a copy of the GNU General Public License
        along with this program; if not, write to the Free Software
        Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
        ******************************************************************************* */

#include <X11/Intrinsic.h>
#include <X11/StringDefs.h>
#include <X11/Xaw3d/Text.h>
#include <X11/Xaw3d/AsciiText.h>
#include <X11/Xaw3d/AsciiSrc.h>
#include <X11/xv/xvCore.h>
#include <X11/xv/xvFont.h>
#include <X11/xv/xvEditField.h>

// *************************************************************************

xvEditField::xvEditField()
{
	alloc=FALSE;
}

// ----------------------------------------------------------------

xvEditField::xvEditField(String name, xvCore & parent, XawTextEditType mode, 
			Dimension sizeH, Dimension sizeL,
			XawAsciiType etype, String datasrc, 
			Boolean resizable, XtCallbackProc callback, String clientdata)
{
	init(name, parent, mode, sizeH, sizeL, etype, datasrc, resizable, callback, clientdata);
}

// *************************************************************************

xvEditField::~xvEditField()
{
	if (alloc) XtDestroyWidget(w);
}

// *************************************************************************

void xvEditField::init(String name, xvCore & parent, XawTextEditType mode, 
	Dimension  sizeH, Dimension sizeL,
	XawAsciiType etype, String datasrc, Boolean resizable, XtCallbackProc callback,
	String clientdata)
{
	init(name, parent.ID(), mode, sizeH, sizeL, etype, datasrc, resizable, callback, clientdata);
}

// ----------------------------------------

void xvEditField::init(String name, Widget parent, XawTextEditType mode, 
	Dimension  sizeH, Dimension sizeL,
	XawAsciiType etype, String datasrc, Boolean resizable, XtCallbackProc callback,
	String clientdata)
{
	Boolean scroll_horiz=! resizable;
	w=XtVaCreateManagedWidget(name, asciiTextWidgetClass, 
		parent, 
		"editType", mode, 
		"resizable", resizable,
		XtNscrollVertical, XawtextScrollWhenNeeded, 
		XtNscrollHorizontal, scroll_horiz, 
		XtNheight, sizeH, XtNwidth, sizeL, 
		NULL); 	
	alloc=TRUE;	
	Source=GetSource();
	XtVaSetValues(Source, XtNtype, etype, XtNstring, datasrc, NULL);
	XtVaGetValues(w, XtNtextSink, &Sink, NULL);
	if (callback!=NULL) XtAddCallback(Source, XtNcallback, callback, (XtPointer) clientdata);
	bfont.init(w, NULL);
}

// ----------------------------------------

void xvEditField::ChangeFont(String fontname)
{
	if (fontname != NULL) {
		bfont.FLoadFont(fontname);
		XtVaSetValues(w, XtNfont, (XtArgVal) bfont.FontRef(), NULL);
	}
}

// -----------------------------------------------------------------

char *xvEditField::ReturnString(char *ptr)
{
	XtVaGetValues(w, XtNstring, &ptr, NULL);
	return(ptr);
}

// ----------------------------------------

void xvEditField::SetSelection(XawTextPosition left, XawTextPosition right)
{
	XawTextSetSelection(w, left, right);
}

// -----------------------------------------

void xvEditField::UnsetSelection()
{
	XawTextUnsetSelection(w);
}

// -----------------------------------------

void xvEditField::Position(XawTextPosition *tbegin, XawTextPosition *tend)
{
	XawTextGetSelectionPos(w, tbegin, tend);
}

// -----------------------------------------

int xvEditField::Replace(XawTextPosition start, XawTextPosition end, XawTextBlock *text)
{
	return(XawTextReplace(w, start, end, text));
}

//------------------------------------------

XawTextPosition xvEditField::Search(XawTextScanDirection dir, XawTextBlock *text)
{
	return(XawTextSearch(w, dir, text));
}

// ------------------------------------------

void xvEditField::Invalidate(XawTextPosition from, XawTextPosition to)
{
	XawTextInvalidate(w, from, to);
}

// ------------------------------------------

void xvEditField::EnableRedisplay()
{
	XawTextEnableRedisplay(w);
}

// ------------------------------------------

void xvEditField::DisableRedisplay()
{
	XawTextDisableRedisplay(w);
}

// ------------------------------------------

void xvEditField::TextDisplay()
{
	XawTextDisplay(w);
}

// ------------------------------------------

XawTextPosition xvEditField::TopPosition()
{
	return(XawTextTopPosition(w));
}

// ------------------------------------------

void xvEditField::SelectionArray(XawTextSelectType *sarray)
{
	XawTextSetSelectionArray(w, sarray);
}

// -------------------------------------------

void xvEditField::InsertionPoint(XawTextPosition pos)
{
	XawTextSetInsertionPoint(w, pos);
}

// -------------------------------------------

XawTextPosition xvEditField::GetInsertionPoint()
{
	return(XawTextGetInsertionPoint(w));
}

// -------------------------------------------

void xvEditField::SetSource(Widget source, XawTextPosition pos)
{
	XawTextSetSource(w, source, pos);
	Source=source;
}

// -------------------------------------------

Widget xvEditField::GetSource()
{
	return(XawTextGetSource(w));
}

// ---------------------------------------------

void xvEditField::DisplayCaret(Boolean visable)
{
	XawTextDisplayCaret(w, visable);
}

// ---------------------------------------------

Boolean xvEditField::Save()
{
	XawAsciiSave(GetSource());
}

// ---------------------------------------------

Boolean xvEditField::SaveAs(String name)
{
	XawAsciiSaveAsFile(GetSource(), name);
}

// ---------------------------------------------

Boolean xvEditField::SourceChanged()
{
	XawAsciiSourceChanged(GetSource());
}

// ---------------------------------------------

XawTextPosition xvEditField::SourceRead(XawTextPosition pos, XawTextBlock *block,
			int length)
{
	return(XawTextSourceRead(Source, pos, block, length));
}

// ---------------------------------------------

XawTextPosition xvEditField::SourceReplace(XawTextPosition start, XawTextPosition end, 
			XawTextBlock *text)
{
	return(XawTextSourceReplace(Source, start, end, text));
}

// ---------------------------------------------

XawTextPosition xvEditField::SourceScan(XawTextPosition pos, XawTextScanType stype,
			XawTextScanDirection dir, int count, Boolean include)
{
	return(XawTextSourceScan(Source, pos, stype, dir, count, include));
}

// ---------------------------------------------

XawTextPosition xvEditField::SourceSearch(XawTextPosition pos, 
			XawTextScanDirection dir, XawTextBlock *block)
{
	return(XawTextSourceSearch(Source, pos, dir, block));
}

// ---------------------------------------------

void xvEditField::Echo(Boolean echo)
{
	XtVaSetValues(w, XtNecho, (XtArgVal) echo, NULL);
}

// ---------------------------------------------

void xvEditField::Wrap(XawTextWrapMode wrap)
{
	XtVaSetValues(w, XtNwrap, (XtArgVal) wrap, NULL);
}

// ---------------------------------------------

void xvEditField::Callback(XtCallbackProc callback, String clientdata)
{
	XtAddCallback(w, XtNcallback, callback, (XtPointer) clientdata);
}

// ---------------------------------------------

void xvEditField::AutoWrap(Boolean autowrap)
{
	XtVaSetValues(w, XtNautoFill, (XtArgVal) autowrap, NULL);
}

// ---------------------------------------------

void xvEditField::DisplayChars(Boolean ctrl)
{
	XtVaSetValues(w, XtNdisplayNonprinting, (XtArgVal) ctrl, NULL);
}

// ---------------------------------------------

void xvEditField::ResizeMode(XawTextResizeMode rmode)
{
	XtVaSetValues(w, XtNresize, (XtArgVal) rmode, NULL);
}

// ---------------------------------------------

void xvEditField::HorizontalScrollBar(XawTextScrollMode hsc)
{
	XtVaSetValues(w, XtNscrollHorizontal, (XtArgVal) hsc, NULL);
}

// ---------------------------------------------

void xvEditField::VerticalScrollBar(XawTextScrollMode hsc)
{
	XtVaSetValues(w, XtNscrollVertical, (XtArgVal) hsc, NULL);
}

// ---------------------------------------------

void xvEditField::SetString(String str)
{
	XtVaSetValues(w, XtNstring, (XtArgVal) str, NULL);
}

// ---------------------------------------------
