
/*     *******************************************************************************
	XVisual GUI Development System for Linux/X-Window
	Copyright (C) 1996 Steve Carrie.

        This program is free software; you can redistribute it and/or modify
        it under the terms of the GNU General Public License as published by
        the Free Software Foundation; either version 2 of the License, or
        (at your option) any later version.

        This program is distributed in the hope that it will be useful,
        but WITHOUT ANY WARRANTY; without even the implied warranty of
        MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
        GNU General Public License for more details.

        You should have received a copy of the GNU General Public License
        along with this program; if not, write to the Free Software
        Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
        ******************************************************************************* */

#include <X11/Intrinsic.h>
#include <X11/StringDefs.h>
#include <X11/Xaw3d/Form.h>
#include <X11/Xaw3d/MenuButton.h>
#include <X11/xv/xvCore.h>
#include <X11/xv/xvFont.h>
#include <X11/xv/xvMenuBar.h>
#include <string.h>

// ********************************

xvMenuBar::xvMenuBar()
{
	alloc=FALSE;
}

// ---------------------------

xvMenuBar::xvMenuBar(String name, xvCore & parent, int num, char **menuinfo, Boolean manage)
{
	init(name, parent, num, menuinfo, manage);
}

// ---------------------------

xvMenuBar::~xvMenuBar()
{
	if (alloc) XtDestroyWidget(w);
}

// ---------------------------

void xvMenuBar::init(char *name, xvCore & parent, int num, char **menuinfo, Boolean manage)
{
	w=XtVaCreateWidget(name, formWidgetClass, 
	  parent.ID(), NULL);

	setupMenu(num, menuinfo);
	alloc=TRUE;
	bfont.init(w, NULL);
	ManageChildren(manage);
}

// -----------------------------------------------------------------

void xvMenuBar::ChangeFont(String fontname)
{
	if (fontname != NULL) {
		bfont.FLoadFont(fontname);
		SetAllResource(XtNfont, (XtArgVal) bfont.FontRef());
	}
}


// ---------------------------

void xvMenuBar::ManageChildren(Boolean manage)
{
	if (manage)
		XtManageChild(w);
	else
		XtUnmanageChild(w);
}

// ---------------------------

void xvMenuBar::setupMenu(int num, char **menuinfo) 
{
	numbuttons=num;

	for (int i=0; i<num; i++) {
	  if (i==0)
	    MenuButtons[i]=XtVaCreateManagedWidget(menuinfo[i], 
	      menuButtonWidgetClass, w, 
	      "menuName", menuinfo[i], NULL);
	  else
	    MenuButtons[i]=XtVaCreateManagedWidget(menuinfo[i], 
	      menuButtonWidgetClass, w, 
	      "menuName", menuinfo[i],
	      "fromHoriz", MenuButtons[i-1],		
	      NULL);

	  menulist[i]= strdup(menuinfo[i]);
        }
}

// ----------------------------

Widget xvMenuBar::GetButton(char *name)
{
	int thisone=-1;

	for(int i=0; i<numbuttons; i++)
	  if (strcmp(name, menulist[i]) == 0) {
	    thisone=i;
	    break;
	  }
          
	if (thisone != -1)
	  return(MenuButtons[thisone]);
	else
	  return(NULL);
}

// ------------------------------------

void xvMenuBar::SetAllResource(String resource, XtArgVal val)
{

	for(int i=0; i<numbuttons; i++)  
		XtVaSetValues(MenuButtons[i], resource, val, NULL);
	
}

// ------------------------------------

void xvMenuBar::SetResource(String name, String resource, XtArgVal val)
{
	int thisone=-1;

	for(int i=0; i<numbuttons; i++)
	  if (strcmp(name, menulist[i]) == 0) {
	    thisone=i;
	    break;
	  }
          
	if (thisone != -1) 
	  XtVaSetValues(MenuButtons[thisone], resource, val, NULL);
	
}